# MessageEndpointType

The output medium to use. Not all medium are equally able to use all fields. All support `text`. In the event of medium which don't support anything other than `text`, the `uri` field is appended with `context` added as a parameter. Examples are web_push, sms, ... 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


